part of cresce_ui;

class CButton extends StatefulWidget {
  final String label;
  final VoidCallback? onTap;
  final CButtonStyle style;
  final double? width;
  final IconData? icon;
  final bool enabled;

  @override
  State<CButton> createState() => _CButtonState();

  const CButton({
    Key? key,
    this.onTap,
    required this.label,
    this.style = const CPrimaryStyle(),
    this.width,
    this.icon,
    this.enabled = true,
  }) : super(key: key);
}

class _CButtonState extends State<CButton> {
  late ButtonState _state;
  late CButtonStyle _style;
  late VoidCallback? onTap;

  @override
  void initState() {
    super.initState();
    if (!widget.enabled) {
      _style = CDisabledStyle();
      onTap = () {};
    } else {
      _style = widget.style;
      onTap = widget.onTap;
    }

    _state = _style.getDefaultState();
  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTapDown: (_) {
        setState(() => _state = _style.getTappedState());
      },
      onTapUp: (_) {
        setState(() => _state = _style.getDefaultState());
        onTap?.call();
      },
      child: Stack(
        children: [
          AnimatedContainer(
            curve: _state.curve,
            width: widget.width,
            height: 40.0,
            decoration: BoxDecoration(
              borderRadius: BorderRadius.circular(25.0),
              color: _state.backgroundColor,
              border: Border.all(width: 1.0, color: _state.borderColor),
            ),
            duration: _state.animationDuration,
            child: Center(
              child: CText(label: widget.label, style: _state.labelStyle),
            ),
          ),
          Positioned(
            height: 40,
            left: 22,
            child: Icon(
              widget.icon,
              size: 18.0,
              color: _state.labelStyle.color,
            ),
          ),
        ],
      ),
    );
  }
}
