part of cresce_ui;

class CDataTable extends StatelessWidget {
  final List<CTableColumn> columns;
  final List<CTableRow> rows;
  final double? height;

  const CDataTable({
    Key? key,
    required this.columns,
    required this.rows,
    this.height = 500.0,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        Row(
          mainAxisAlignment: MainAxisAlignment.center,
          children: columns
              .map((e) => Padding(
                    padding: const EdgeInsets.symmetric(horizontal: 3.0),
                    child: CPageTitle(title: e.label, width: e.width),
                  ))
              .toList(),
        ),
        SizedBox(
          height: height,
          child: Theme(
            data: Theme.of(context).copyWith(dividerColor: Colors.transparent),
            child: SingleChildScrollView(
              child: DataTable(
                headingTextStyle: CTextStyles.captionPrimary,
                showBottomBorder: false,
                dataRowHeight: 32.0,
                columnSpacing: 6.0,
                headingRowHeight: 0.0,
                columns: _mapColumns(),
                rows: _mapRows(),
                dividerThickness: 0.0,
              ),
            ),
          ),
        ),
      ],
    );
  }

  List<DataColumn> _mapColumns() =>
      columns.map((e) => const DataColumn(label: SizedBox())).toList();

  List<DataRow> _mapRows() =>
      rows.map((row) => DataRow(cells: _mapDataToCells(row))).toList();

  List<DataCell> _mapDataToCells(CTableRow row) {
    List<DataCell> cells = [];

    for (var i = 0; i < row.data.length; ++i) {
      cells.add(
        DataCell(
          CText(
            label: row.data[i],
            style: CTextStyles.fieldSecondaryVar1,
            width: columns[i].width,
            align: columns[i].dataAlign,
          ),
        ),
      );
    }

    return cells;
  }
}

class CTableRow {
  final List<String> data;

  CTableRow(this.data);
}

class CTableColumn {
  final String label;
  final double width;
  final TextAlign? dataAlign;

  CTableColumn({
    required this.label,
    required this.width,
    this.dataAlign,
  });
}
