part of cresce_ui;

class CInputDate extends StatefulWidget {
  final String label;
  final IconData? icon;
  final void Function(DateTime date)? onPickDate;
  final String Function(DateTime date)? formatDate;
  final DateTime? initialDate;

  const CInputDate({
    Key? key,
    required this.label,
    this.icon,
    this.onPickDate,
    this.formatDate,
    this.initialDate,
  }) : super(key: key);

  @override
  State<CInputDate> createState() => _CInputDateState();
}

class _CInputDateState extends State<CInputDate> {
  late TextEditingController controller;
  late DateTime date;

  String _format(DateTime date) =>
      widget.formatDate == null ? date.toString() : widget.formatDate!(date);

  @override
  void initState() {
    super.initState();
    date = widget.initialDate ?? DateTime.now();
    controller = TextEditingController(text: _format(date));
    controller.addListener(handleDateChange);
    handleDateChange();
  }

  void handleDateChange() => widget.onPickDate?.call(date);

  @override
  void dispose() {
    super.dispose();
    controller.removeListener(handleDateChange);
    controller.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return CInputText(
      label: widget.label,
      icon: widget.icon,
      field: controller,
      onChanged: (value) => handleDateChange(),
      readonly: true,
      onTap: () async {
        var date = await showDatePicker(
          context: context,
          initialEntryMode: DatePickerEntryMode.calendarOnly,
          initialDate: widget.initialDate ?? DateTime.now(),
          firstDate: DateTime(DateTime.now().year - 10),
          lastDate: DateTime(DateTime.now().year + 10),
          builder: (context, child) => Theme(
            data: ThemeData.light().copyWith(
              colorScheme: ColorScheme.light(
                primary: CColors.primary,
              ),
            ),
            child: child!,
          ),
        );
        if (date == null) return;
        this.date = date;
        controller.text = _format(date);
      },
    );
  }
}
