part of cresce_ui;

class CInputDropdown extends StatefulWidget {
  final String label;
  final void Function(Object value)? onChanged;
  final List<Object> items;

  const CInputDropdown({
    Key? key,
    required this.label,
    required this.items,
    this.onChanged,
  }) : super(key: key);

  @override
  State<CInputDropdown> createState() => _CInputDropdownState();
}

class _CInputDropdownState extends State<CInputDropdown> {
  late TextEditingController controller;

  @override
  void initState() {
    super.initState();
    controller = TextEditingController();
    controller.text = widget.items.first.toString();
    widget.onChanged?.call(controller.text);
  }

  @override
  void dispose() {
    controller.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return CInputText(
      label: widget.label,
      field: controller,
      readonly: true,
      onTap: () async {
        var value = await _getSelectedItem(context);
        if (value == null) return;
        controller.text = value.toString();
        widget.onChanged?.call(value);
      },
    );
  }

  Future<Object?> _getSelectedItem(BuildContext context) async {
    return await showDialog<Object>(
      context: context,
      builder: (context) => _DropdownModal(items: widget.items),
    );
  }
}

class _DropdownModal extends StatelessWidget {
  final List<Object> items;

  const _DropdownModal({Key? key, required this.items}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Center(
      child: CSmallModal(
        size: Size(300, items.length * 50),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.center,
          children: items
              .map(
                (e) => GestureDetector(
                  onTap: () => Navigator.pop(context, e),
                  child: Padding(
                    padding: const EdgeInsets.symmetric(
                      vertical: 13,
                      horizontal: 20,
                    ),
                    child: Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        Padding(
                          padding: const EdgeInsets.only(left: 8),
                          child: CText(
                            label: e.toString(),
                            style: CTextStyles.captionSecondaryVar1,
                          ),
                        ),
                        const CDivider(),
                      ],
                    ),
                  ),
                ),
              )
              .toList(),
        ),
      ),
    );
  }
}
