part of cresce_ui;

class CMonthNavigator extends StatefulWidget {
  final void Function(DateTime date)? onChange;
  final double? width;
  final Locale locale;
  final DateTime? initialDate;

  const CMonthNavigator({
    Key? key,
    this.onChange,
    this.width,
    this.initialDate,
    this.locale = const Locale('en', 'US'),
  }) : super(key: key);

  @override
  State<CMonthNavigator> createState() => _CMonthNavigatorState();
}

class _CMonthNavigatorState extends State<CMonthNavigator> {
  late DateTime _date;

  late VoidCallback swipeDirection;

  @override
  void initState() {
    super.initState();
    _date = widget.initialDate ?? DateTime.now();
    _date = DateTime(_date.year, _date.month, _date.day);
    swipeDirection = () {};
  }

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      width: widget.width,
      child: Container(
        color: Colors.transparent,
        child: Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: <Widget>[
            GestureDetector(
              onTap: () => _decrementMonth(),
              child: Container(
                color: Colors.transparent,
                width: 30,
                height: 30,
                child: Center(
                  child: Text('<', style: CTextStyles.fieldPrimary),
                ),
              ),
            ),
            GestureDetector(
              onPanUpdate: (details) => swipeDirection =
                  details.delta.dx < 0 ? _incrementMonth : _decrementMonth,
              onPanEnd: (details) => swipeDirection.call(),
              child: Text(
                DateFormat('MMMM/yy', widget.locale.toString()).format(_date),
                style: CTextStyles.fieldPrimary,
              ),
            ),
            GestureDetector(
              onTap: () => _incrementMonth(),
              child: Container(
                color: Colors.transparent,
                width: 30,
                height: 30,
                child: Center(
                  child: Text('>', style: CTextStyles.fieldPrimary),
                ),
              ),
            ),
          ],
        ),
      ),
    );
  }

  void _decrementMonth() {
    setState(() {
      _date = _date.subtract(Duration(days: _date.day + 1));
      _date = DateTime(_date.year, _date.month, 1);
    });
    widget.onChange?.call(_date);
  }

  void _incrementMonth() {
    setState(() {
      _date = _date.add(Duration(days: _date.day + 31));
      _date = DateTime(_date.year, _date.month, 1);
    });
    widget.onChange?.call(_date);
  }
}
